@@ -30,7 +30,7 @@ x <- M5data[, 1:2]
 (clus.a <- tclust (x, k = 3, alpha = 0.1, restr.fact =  1,
                   restr = "eigen", equal.weights = TRUE, warnings = 1))
 (clus.b <- tclust (x, k = 3, alpha = 0.1, restr.fact =  1,
-                  restr = "sigma", equal.weights = TRUE))
+                    equal.weights = TRUE, warnings = 1))
 (clus.c <- tclust (x, k = 3, alpha = 0.1, restr.fact =  1,
                   restr = "deter", equal.weights = TRUE, iter.max = 100,
 		  warnings = 1))
